@@ -1,7 +1,7 @@
 #!/usr/bin/perl -w
 ################################################################################
 #
-# Copyright (c) 2005-2020 Marcus Holland-Moritz. All rights reserved.
+# Copyright (c) 2005-2024 Marcus Holland-Moritz. All rights reserved.
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
 #
@@ -20,27 +20,12 @@ BEGIN {
 -->   I will only run some very basic tests now.
 
 ENDWARN
-    eval q{
-      use Test::Harness;
-      $Test::Harness::switches = "-w";
-    };
   }
-  else {
-    eval { $thv = `$^X -MTest::Harness -leprint\$Test::Harness::VERSION` };
 
-    eval q{ use lib './support' } unless defined $thv && $thv >= 2.62;
-
-    eval q{
-      use File::Spec;
-      use Test::Harness;
-      use Cwd;
-
-      $lib = File::Spec->catfile(getcwd, 'support');
-      $lib = qq["$lib"] if $lib =~ /\s/;
-
-      $Test::Harness::switches = "-I$lib -w";
-    };
-  }
+  eval q{
+    use Test::Harness;
+    $Test::Harness::switches = "-w";
+  };
 }
 
 @tests = @ARGV ? @ARGV : find_tests();
